
.. _l-base-model-sir:

Base implementation for SIR models
==================================

.. contents::
    :local:

BaseSIR
+++++++

.. autoclass:: aftercovid.models._base_sir.BaseSIR
    :members:

BaseSIRSimulation
+++++++++++++++++

.. autoclass:: aftercovid.models._base_sir_sim.BaseSIRSimulation
    :members:

BaseSIREstimation
+++++++++++++++++

.. autoclass:: aftercovid.models._base_sir_estimation.BaseSIREstimation
    :members:
